{% set content = _('{actor} deleted the organization {organization}').format(
    actor=ah.actor(activity),
    organization=ah.organization(activity)
  )|safe
%}

{% snippet "snippets/activities/activity_template.html", activity=activity, content=content, show_details=show_details, icon="fa-briefcase" %}
