{% ckan_extends %}

{% block secondary %}
    <aside class="secondary col-md-3">
        {% block secondary_content %}{{ super() }}{% endblock %}
    </aside>
{% endblock secondary %}

{% block primary %}
    <div class="primary col-md-9 col-xs-12" role="main">
        {% block primary_content %}{{ super() }}{% endblock %}
    </div>
{% endblock primary %}
