{% set content = _('{actor} signed up').format(
    actor=ah.actor(activity)
    )|safe
%}

{% snippet "snippets/activities/activity_template.html", activity=activity, content=content, show_details=show_details, icon="fa-user" %}
