{% set content = _('{actor} updated the organization {organization}').format(actor=ah.actor(activity), organization=ah.organization(activity))|safe %}
{% set changes = h.url_for('activity.organization_changes', id=activity.id) %}

{% snippet "snippets/activities/activity_template.html", activity=activity, content=content, show_details=show_details, changes=changes %}
