.activity-list {
    padding-left: 0;
}

.activity-list .activity-item {
    display: flex;
    align-items: center;
    margin-bottom: 1rem;
    position: relative;
    border: 1px solid #ced4da;
    border-radius: 0.3rem;
    padding: 0.3rem;
}

.activity-list .activity-item .activity-item--icon {
    position: absolute;
    left: -15px;
    top: -14px;
    margin: 0;
    background: white;
    padding: 3px 6px;
    border-radius: 50%;
}

.activity-list .activity-item .activity-item--wrapper {
    display: flex;
    flex-direction: column;
    width: 100%;
    padding: 0.3rem;
}

.activity-list .activity-item .activity-item--wrapper .activity-item--meta {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    column-gap: 0.3rem;
}

.activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--version,
.activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--changes {
    margin-top: 0.5rem;
    flex-basis: 100%;
}

.activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--version .btn,
.activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--changes .btn {
    width: 100%;
}

.activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--date {
    color: #757575;
    position: absolute;
    right: 11px;
    top: -11px;
    background: white;
    padding: 0 5px;
}

.activity-list .activity-item .activity-item--icon i {
    color: #999999;
}

.activity-list .activity-item.failure .activity-item--icon i {
    color: #B95252;
}

.activity-list .activity-item.success .activity-item--icon i {
    color: #69A67A;
}

.activity-list .activity-item.changed-group .activity-item--icon i {
    color: #767DCE;
}

.activity-list .activity-item.changed-package .activity-item--icon i {
    color: #8c76ce;
}

.activity-list .activity-item.changed-package_extra .activity-item--icon i {
    color: #769ace;
}

.activity-list .activity-item.changed-user .activity-item--icon i {
    color: #76b8ce;
}

.activity-list .activity-item.changed-organization .activity-item--icon i {
    color: #699fa6;
}

.activity-list .activity-item.deleted-group .activity-item--icon i {
    color: #B95252;
}

.activity-list .activity-item.deleted-package .activity-item--icon i {
    color: #b97452;
}

.activity-list .activity-item.deleted-package_extra .activity-item--icon i {
    color: #b95274;
}

.activity-list .activity-item.deleted-organization .activity-item--icon i {
    color: #b95297;
}

.activity-list .activity-item.new-group .activity-item--icon i {
    color: #69A67A;
}

.activity-list .activity-item.new-package .activity-item--icon i {
    color: #69a68e;
}

.activity-list .activity-item.new-package_extra .activity-item--icon i {
    color: #6ca669;
}

.activity-list .activity-item.new-user .activity-item--icon i {
    color: #69a6a3;
}

.activity-list .activity-item.new-organization .activity-item--icon i {
    color: #81a669;
}

.activity-list .activity-item.deleted-related-item .activity-item--icon i {
    color: #b9b952;
}

.activity-list .activity-item.follow-dataset .activity-item--icon i {
    color: #767DCE;
}

.activity-list .activity-item.follow-user .activity-item--icon i {
    color: #8c76ce;
}

.activity-list .activity-item.new-related-item .activity-item--icon i {
    color: #95a669;
}

.activity-list .activity-item.follow-group .activity-item--icon i {
    color: #8ba669;
}

@media (min-width: 576px) {

    .activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--version,
    .activity-list .activity-item .activity-item--wrapper .activity-item--meta .meta--changes {
        flex-basis: auto;
    }
}

.activity_buttons {
    display: flex;
    gap: 0.5rem;
}

.activity_buttons>a.btn.disabled {
    color: inherit;
    opacity: 0.7;
}

.popover {
    width: 300px;
}

.popover .popover-title {
    font-weight: bold;
    margin-bottom: 0;
}

.popover p.about {
    margin: 0 0 10px 0;
}

.popover .popover-close {
    float: right;
    text-decoration: none;
}

.popover .empty {
    padding: 10px;
    color: #6E6E6E;
    font-style: italic;
}

.select-time {
    width: 250px;
    display: inline;
}

br.line-height2 {
    line-height: 2;
}

.pull-right {
    float: right;
}
